// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

/*
 * Provides helper methods associated with database access.
 */
public class DB2Helper {

    private static Logger logger = Logger.getLogger( "DB2Helper" );

    private static final String DATASOURCE_JNDI_DEFAULT = "jdbc/db2emitter";

    private static Object lock = new Object( );

    private static DataSource dataSource = null;

    /*
     * Initialize the data source. The default JNDI name is used if no explicit
     * one is configured via an EJB deployment descriptor's dataSourceJNDI
     * environment entry (i.e., "java:comp/env/dataSourceJNDI").
     */
    public static DataSource getDataSource( ) throws NamingException {
        synchronized( lock ) {
            if( dataSource != null ) {
                return dataSource;
            }

            InitialContext ic = null;
            String dataSourceJNDI = null;

            try {
                ic = new InitialContext( );
                dataSourceJNDI = (String)ic.lookup( "java:comp/env/dataSourceJNDI" );
            }
            catch( NamingException ne ) {
                logger.log( Level.INFO, "Unable to lookup of the environment entry \"dataSourceJNDI\"." );
                throw ne;
            }

            if( ( dataSourceJNDI == null ) || ( dataSourceJNDI.length( ) == 0 ) ) {
                dataSourceJNDI = DATASOURCE_JNDI_DEFAULT;
            }

            try {
                if( ic == null )
                    ic = new InitialContext( );
                dataSource = (DataSource)ic.lookup( dataSourceJNDI );
            }
            catch( NamingException ne ) {
                logger.log( Level.INFO, "Unable to lookup of the datasource with the JNDI name " + dataSourceJNDI + "." );
                throw ne;
            }

            return dataSource;
        }
    }
}
