// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter;

import java.util.Collection;
import java.util.Iterator;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.ibm.wbimonitor.samples.db2emitter.exception.EventTablePollerException;
import com.ibm.wbimonitor.samples.emitterframework.EventHandler;
import com.ibm.wbimonitor.samples.emitterframework.exception.EventHandlerException;
import com.ibm.websphere.scheduler.TaskStatus;

/*
 * This class implements the business logic for the EventMediator stateless
 * session EJB. The EventMediator stateless session EJB is also the task handler
 * for the task scheduled with the WAS Scheduler. As such, this class also
 * implements the necessary interface: process().
 */
public class EmissionController implements javax.ejb.SessionBean {

    Logger logger = Logger.getLogger( "EmissionController" );

    private javax.ejb.SessionContext mySessionCtx;

    /*
     * getSessionContext
     */
    public javax.ejb.SessionContext getSessionContext( ) {
        return mySessionCtx;
    }

    /*
     * setSessionContext
     */
    public void setSessionContext( javax.ejb.SessionContext ctx ) {
        mySessionCtx = ctx;
    }

    /*
     * ejbCreate
     */
    public void ejbCreate( ) throws javax.ejb.CreateException {}

    /*
     * ejbActivate
     */
    public void ejbActivate( ) {}

    /*
     * ejbPassivate
     */
    public void ejbPassivate( ) {}

    /*
     * ejbRemove
     */
    public void ejbRemove( ) {}

    /*
     * This method implements the process interface of a WAS Scheduler
     * TaskHandler. This method will invoke EventTablePoller to poll the events
     * table in the database. For each event in the events table the
     * DB2EventHandler will be invoked to convert the detailed event information
     * into a CBE and emit it to the CEI. After the event is processed by the
     * DB2EventHandler, the event record is "purged" to the logging table.
     */
    public void process( TaskStatus status ) {

        logger.entering( "EmissionController", "process" );

        EventHandler handler = new DB2EventHandler( );
        Collection c;
        try {
            c = EventTablePoller.poll( );
        }
        catch( EventTablePollerException etpe ) {
            logger.log( Level.INFO, etpe.getMessage( ), etpe );
            return;
        }

        Iterator iterator = c.iterator( );
        while( iterator.hasNext( ) ) {
            try {
                EventTableBean bean = (EventTableBean)iterator.next( );
                try {
                    handler.handle( bean );
                    EventTablePoller.purge( bean, false );
                }
                catch( EventHandlerException e ) {
                    logger.log( Level.INFO, e.getMessage( ), e );
                    EventTablePoller.purge( bean, true );
                }
            }
            catch( EventTablePollerException e ) {
                logger.log( Level.INFO, e.getMessage( ), e );
            }
        }

        logger.exiting( "EmissionController", "process" );
    }
}