// ===================================================================
//(C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                        
// Licensed Materials - Property of IBM
//                                                       
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//           
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                        
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter;

import java.util.logging.Logger;

import com.ibm.wbimonitor.samples.emitterframework.poll.EmitterFWTaskSchedulerUtil;

/*
 * This class implements the business logic for the TaskScheduler stateless
 * session EJB. The TaskScheduler stateless session EJB is also a startup
 * session EJB. As such, this class also implements the necessary interfaces:
 * start() and stop().
 */
public class TaskSchedulerBean implements javax.ejb.SessionBean {

    private static Logger logger = Logger.getLogger( "TaskSchedulerBean" );

    private javax.ejb.SessionContext mySessionCtx;

    /*
     * Provides utility methods to schedule and unschedule the periodic polling
     * task.
     */
    private EmitterFWTaskSchedulerUtil taskScheduler;

    /*
     * getSessionContext
     */
    public javax.ejb.SessionContext getSessionContext( ) {
        return mySessionCtx;
    }

    /*
     * setSessionContext
     */
    public void setSessionContext( javax.ejb.SessionContext ctx ) {
        mySessionCtx = ctx;
    }

    /*
     * ejbActivate
     */
    public void ejbActivate( ) {}

    /*
     * ejbPassivate
     */
    public void ejbPassivate( ) {}

    /*
     * ejbRemove
     */
    public void ejbRemove( ) {}

    /*
     * ejbCreate
     */
    public void ejbCreate( ) throws javax.ejb.CreateException {}

    /*
     * This method implements the start interface of a startup EJB. It delegates
     * to the EmitterFWTaskSchedulerUtil utility class to schedule a periodic
     * task
     */
    public boolean start( ) {
        logger.entering( "TaskSchedulerBean", "start" );
        taskScheduler = new EmitterFWTaskSchedulerUtil( "ejb/db2emitter/EventMediator", "DB2EmitterTaskScheduler" );
        logger.exiting( "TaskSchedulerBean", "start" );
        return ( taskScheduler.start( ) );
    }

    /*
     * This method implements the stop interface of a startup EJB. It delegates
     * to the EmitterFWTaskSchedulerUtil utility class to remove from the
     * scheduler the periodic task scheduled during startup.
     */
    public void stop( ) {
        logger.entering( "TaskSchedulerBean", "stop" );
        taskScheduler.stop( );
        logger.exiting( "TaskSchedulerBean", "stop" );
    }
}
