// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter.formatter;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.eclipse.hyades.logging.events.cbe.CommonBaseEvent;
import org.eclipse.hyades.logging.events.cbe.ComponentIdentification;
import org.eclipse.hyades.logging.events.cbe.EventFactory;
import org.eclipse.hyades.logging.events.cbe.EventFactoryFactory;
import org.eclipse.hyades.logging.events.cbe.ExtendedDataElement;
import org.eclipse.hyades.logging.events.cbe.Situation;

import com.ibm.wbimonitor.samples.db2emitter.EventTableBean;
import com.ibm.wbimonitor.samples.db2emitter.exception.EventRetrieveFailedException;
import com.ibm.wbimonitor.samples.db2emitter.retriever.ORDEREventRetrieverImpl;
import com.ibm.wbimonitor.samples.emitterframework.CBEHelper;
import com.ibm.wbimonitor.samples.emitterframework.EventFormatter;
import com.ibm.wbimonitor.samples.emitterframework.exception.EventFormatFailedException;

/*
 * This class implements the EventFormatter interface.
 */
public class ORDERFormatterImpl implements EventFormatter {

    /*
     * This method implements the format interface of EventFormatter.
     */
    public CommonBaseEvent format( Object o ) throws EventFormatFailedException {
        Object retrieved = null;
        ORDEREventRetrieverImpl retriever = null;
        CommonBaseEvent event = null;
        EventTableBean bean = null;
        String activityName = null;
        String orderStatus = null;
        String orderNumber = null;

        try {
            retriever = new ORDEREventRetrieverImpl( );
            retrieved = retriever.retrieve( o );
            bean = ( (EventTableBean)o );
            char trigger = (char)bean.getTrigger( );

            if( trigger == 'D' ) {
                activityName = "DB2_OrderDeleted";
                orderNumber = (String)retrieved;
            }
            else {
                orderNumber = new Integer( ( (ResultSet)retrieved ).getInt( "ORDERID" ) ).toString( );
                orderStatus = ( (ResultSet)retrieved ).getString( "STATUS" );

                if( ( trigger == 'C' ) && ( "RECEIVED".equalsIgnoreCase( orderStatus ) ) )
                    activityName = "DB2_OrderReceived";

                else if( trigger == 'U' ) {
                    if( "COMPLETED_SIGNED".equalsIgnoreCase( orderStatus ) )
                        activityName = "DB2_PkgReceiptSignatureRecorded";
                    else
                        activityName = "DB2_OrderUpdated";
                }
                else
                    throw new EventFormatFailedException( "The event recorded is not recognized.  It is not a CREATE or DELETE or UPDATE." );
            }

            EventFactory eventFactory = (EventFactory)EventFactoryFactory.createEventFactory( );
            event = eventFactory.createCommonBaseEvent( );
            CBEHelper.setupCBE( event );
            event.setCreationTimeAsLong( System.currentTimeMillis( ) );
            event.setExtensionName( "ActivityEvent" );
            event.setSeverity( (short)10 );
            event.setGlobalInstanceId( eventFactory.createGlobalInstanceId( ) );

            Situation situation = eventFactory.createSituation( );
            event.setSituation( situation );
            situation.setStopSituation( "EXTERNAL", "STOP_COMPLETED", "SUCCESSFUL" );

            ComponentIdentification componentId = eventFactory.createComponentIdentification( );
            event.setSourceComponentId( componentId );
            componentId.setApplication( "DB2" );
            componentId.setComponent( "db2.exe" );
            componentId.setSubComponent( "db2syscs.exe" );
            componentId.setComponentType( "http://www.ibm.com/namespaces/db2" );
            componentId.setComponentIdType( "db2syscs.exe" );
            componentId.setLocation( "lycos" );
            componentId.setLocationType( "IPV4" );

            ExtendedDataElement activityEventData = event.addExtendedDataElementWithNoValue( "ActivityEventData" );
            activityEventData.addChild( "activityName", activityName );
            activityEventData.addChild( "eventType", "completed" );
            activityEventData.addChild( "activityDisplayState", "Completed" );
            activityEventData.addChildWithDateAsLongValue( "startTime", bean.getTimestamp( ).getTime( ) );
            activityEventData.addChildWithDateAsLongValue( "endTime", bean.getTimestamp( ).getTime( ) );

            ExtendedDataElement orderBOData = event.addExtendedDataElementWithNoValue( "OrderBOData" );
            orderBOData.addChild( "orderNumber", orderNumber );

            if( trigger != 'D' ) {
                orderBOData.addChild( "customerNumber", ( (ResultSet)retrieved ).getString( "CUSTOMERID" ) );
                orderBOData.addChild( "orderState", orderStatus );
                orderBOData.addChild( "city", ( (ResultSet)retrieved ).getString( "CITY" ) );
                orderBOData.addChild( "country", ( (ResultSet)retrieved ).getString( "COUNTRY" ) );
                orderBOData.addChild( "productNumber", ( (ResultSet)retrieved ).getString( "PRODUCTID" ) );
                orderBOData.addChildWithIntValue( "quantity", ( (ResultSet)retrieved ).getInt( "QUANTITY" ) );
                orderBOData.addChildWithDoubleValue( "totalPrice", ( (ResultSet)retrieved ).getDouble( "TOTALPRICE" ) );
                orderBOData.addChildWithBooleanValue( "approveWithReview", ( (ResultSet)retrieved ).getBoolean( "AWR" ) );
                orderBOData.addChildWithBooleanValue( "accountInGoodStanding", ( (ResultSet)retrieved ).getBoolean( "AIGS" ) );
                orderBOData.addChildWithBooleanValue( "acceptableCreditRisk", ( (ResultSet)retrieved ).getBoolean( "ACR" ) );
            }

        }
        catch( EventRetrieveFailedException e ) {
            throw new EventFormatFailedException( "Cannot retrieve from the order table.", e );
        }
        catch( SQLException e ) {
            throw new EventFormatFailedException( "Cannot retrieve from the order table.", e );
        }
        finally {
            retriever.close( );
        }

        return event;
    }
}