// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter.retriever;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.ibm.wbimonitor.samples.db2emitter.AbstractEventRetriever;
import com.ibm.wbimonitor.samples.db2emitter.EventTableBean;
import com.ibm.wbimonitor.samples.db2emitter.exception.EventRetrieveFailedException;

/*
 * This class implements the AbstractEventRetriever abstract class.
 */
public class ORDEREventRetrieverImpl extends AbstractEventRetriever {

    private static String CREATE_EVENT_SQL = "SELECT * FROM \"ORDER\" WHERE ORDERID = ?";

    private static String UPDATE_EVENT_SQL = "SELECT * FROM \"ORDER\" WHERE ORDERID = ?";

    public ORDEREventRetrieverImpl( ) throws EventRetrieveFailedException {
        super( );
    }

    /*
     * This method implements the retrieve abstract method declared by
     * AbstractEventRetriever.
     */
    public Object retrieve( Object o ) throws EventRetrieveFailedException {
        EventTableBean bean = (EventTableBean)o;
        switch( bean.getTrigger( ) ) {
            case 'C':
                return retrieveForType( bean, CREATE_EVENT_SQL );
            case 'U':
                return retrieveForType( bean, UPDATE_EVENT_SQL );
            case 'D':
                return bean.getKeyValue( );
        }
        throw new EventRetrieveFailedException( "It is a wrong type [" + (char)bean.getTrigger( ) + "]" );
    }

    private ResultSet retrieveForType( EventTableBean bean, String sql ) throws EventRetrieveFailedException {
        String keyType = bean.getKeyType( );
        if( !keyType.equals( "INT" ) ) {
            throw new EventRetrieveFailedException( "It is a wrong keytype [" + keyType + "]" );
        }
        int key;
        try {
            key = Integer.parseInt( bean.getKeyValue( ) );
        }
        catch( NumberFormatException e1 ) {
            throw new EventRetrieveFailedException( "It is a wrong keyValue [" + bean.getKeyValue( ) + "]" );
        }

        PreparedStatement stmt = null;
        ResultSet rs = null;
        try {
            stmt = connection.prepareStatement( sql, ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_UPDATABLE );
            stmt.setInt( 1, key );
            rs = stmt.executeQuery( );

            if( rs.next( ) == false ) {
                throw new EventRetrieveFailedException( "There is no records with keyValue [" + key + "]" );
            }

            return rs;
        }
        catch( SQLException e ) {
            throw new EventRetrieveFailedException( "Cannot retrieve from the order table", e );
        }
    }

}